@@ -17,9 +17,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 import os
-import subprocess
 from gettext import gettext as _
-from hashlib import md5
 from time import time
 from urllib.parse import unquote
 
@@ -41,6 +39,7 @@ from pitivi.configure import VERSION
 from pitivi.dialogs.prefs import PreferencesDialog
 from pitivi.effects import EffectListWidget
 from pitivi.mediafilespreviewer import PreviewWidget
+from pitivi.medialibrary import AssetThumbnail
 from pitivi.medialibrary import MediaLibraryWidget
 from pitivi.project import ProjectSettingsDialog
 from pitivi.settings import GlobalSettings
@@ -51,10 +50,11 @@ from pitivi.transitions import TransitionsListWidget
 from pitivi.utils.loggable import Loggable
 from pitivi.utils.misc import path_from_uri
 from pitivi.utils.misc import show_user_manual
-from pitivi.utils.ui import beautify_length
+from pitivi.utils.ui import beautify_missing_asset
 from pitivi.utils.ui import beautify_time_delta
 from pitivi.utils.ui import clear_styles
 from pitivi.utils.ui import info_name
+from pitivi.utils.ui import PADDING
 from pitivi.utils.ui import SPACING
 from pitivi.utils.ui import TIMELINE_CSS
 from pitivi.viewer.viewer import ViewerContainer
@@ -105,10 +105,6 @@ GlobalSettings.addConfigOption('lastCurrentVersion',
                                section='version',
                                key='last-current-version',
                                default='')
-GlobalSettings.addConfigOption('timelineAutoRipple',
-                               section='user-interface',
-                               key='timeline-autoripple',
-                               default=False)
 
 
 class MainWindow(Gtk.ApplicationWindow, Loggable):
@@ -437,30 +433,30 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         self._headerbar.pack_start(self.render_button)
 
     def _set_keyboard_shortcuts(self):
-        self.app.shortcuts.register_group("win", _("Project"))
+        self.app.shortcuts.register_group("win", _("Project"), position=20)
         self.save_action = Gio.SimpleAction.new("save", None)
         self.save_action.connect("activate", self._saveProjectCb)
         self.add_action(self.save_action)
-        self.app.shortcuts.add("win.save", ["<Control>s"],
+        self.app.shortcuts.add("win.save", ["<Primary>s"],
                                _("Save the current project"))
         self.save_button.set_action_name("win.save")
 
         self.new_project_action = Gio.SimpleAction.new("new-project", None)
         self.new_project_action.connect("activate", self._newProjectMenuCb)
         self.add_action(self.new_project_action)
-        self.app.shortcuts.add("win.new-project", ["<Control>n"],
+        self.app.shortcuts.add("win.new-project", ["<Primary>n"],
                                _("Create a new project"))
 
         self.open_project_action = Gio.SimpleAction.new("open-project", None)
         self.open_project_action.connect("activate", self._openProjectCb)
         self.add_action(self.open_project_action)
-        self.app.shortcuts.add("win.open-project", ["<Control>o"],
+        self.app.shortcuts.add("win.open-project", ["<Primary>o"],
                                _("Open a project"))
 
         self.save_as_action = Gio.SimpleAction.new("save-as", None)
         self.save_as_action.connect("activate", self._saveProjectAsCb)
         self.add_action(self.save_as_action)
-        self.app.shortcuts.add("win.save-as", ["<Control><Shift>s"],
+        self.app.shortcuts.add("win.save-as", ["<Primary><Shift>s"],
                                _("Save the current project as"))
 
         self.help_action = Gio.SimpleAction.new("help", None)
@@ -478,7 +474,7 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         import_asset_action = Gio.SimpleAction.new("import-asset", None)
         import_asset_action.connect("activate", self.__import_asset_cb)
         self.add_action(import_asset_action)
-        self.app.shortcuts.add("win.import-asset", ["<Control>i"],
+        self.app.shortcuts.add("win.import-asset", ["<Primary>i"],
                                _("Add media files to your project"))
 
     def __import_asset_cb(self, unusdaction, unusedparam):
@@ -530,7 +526,7 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         # to do a better job (sizing, zooming, metadata, editing, etc.)
         # than the user's favorite image viewer.
         if asset.is_image():
-            subprocess.call(['xdg-open', str(path_from_uri(asset.get_id()))])
+            Gio.AppInfo.launch_default_for_uri(asset.get_id(), None)
         else:
             preview_window = PreviewAssetWindow(asset, self)
             preview_window.preview()
@@ -605,15 +601,15 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         abt.set_website(APPURL)
 
         if in_devel():
-            version_str = _("Development version: %s" % GITVERSION)
-        elif not self.app.isLatest():
-            version_str = _("Version %(cur_ver)s — %(new_ver)s is available" %
-                            {"cur_ver": GITVERSION,
-                             "new_ver": self.app.getLatest()})
-        elif GITVERSION:
-            version_str = _("Version %s" % GITVERSION)
+            version_str = _("Development version: %s") % GITVERSION
         else:
-            version_str = _("Version %s" % VERSION)
+            version = GITVERSION if GITVERSION.startswith(VERSION) else VERSION
+            if not self.app.isLatest():
+                version_str = _("Version %(cur_ver)s — %(new_ver)s is available") % \
+                    {"cur_ver": version,
+                     "new_ver": self.app.getLatest()}
+            else:
+                version_str = _("Version %s") % version
         abt.set_version(version_str)
 
         comments = ["",
@@ -647,6 +643,9 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
                      "Or you can run: git shortlog -s -n")
                    % "http://ohloh.net/p/pitivi/contributors", ]
         abt.set_authors(authors)
+        # Translators: See
+        # https://developer.gnome.org/gtk3/stable/GtkAboutDialog.html#gtk-about-dialog-set-translator-credits
+        # for details on how this is used.
         translators = _("translator-credits")
         if translators != "translator-credits":
             abt.set_translator_credits(translators)
@@ -813,12 +812,12 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
             last_saved = max(
                 os.path.getmtime(path), project_manager.time_loaded)
             time_delta = time() - last_saved
-            secondary.props.label = _("If you don't save, "
-                                      "the changes from the last %s will be lost."
-                                      % beautify_time_delta(time_delta))
+            message = _("If you don't save, "
+                        "the changes from the last %s will be lost.") % \
+                beautify_time_delta(time_delta)
         else:
-            secondary.props.label = _("If you don't save, "
-                                      "your changes will be lost.")
+            message = _("If you don't save, your changes will be lost.")
+        secondary.props.label = message
 
         # put the text in a vbox
         vbox = Gtk.Box(homogeneous=False, spacing=SPACING * 2)
@@ -931,45 +930,46 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         dialog.set_transient_for(self)
         dialog.set_default_response(Gtk.ResponseType.OK)
 
-        # This box will contain the label and optionally a thumbnail
+        # This box will contain widgets with details about the missing file.
+        vbox = Gtk.Box()
+        vbox.set_orientation(Gtk.Orientation.VERTICAL)
+
+        label_start = Gtk.Label()
+        label_start.set_markup(_("The following file could not be found:"))
+        label_start.set_xalign(0)
+        vbox.pack_start(label_start, False, False, 0)
+
         hbox = Gtk.Box()
         hbox.set_orientation(Gtk.Orientation.HORIZONTAL)
-        hbox.set_spacing(SPACING)
+        hbox.set_margin_top(PADDING)
+        hbox.set_spacing(PADDING * 2)
 
-        # Check if we have a thumbnail available.
-        # This can happen if the file was moved or deleted by an application
-        # that does not manage Freedesktop thumbnails. The user is in luck!
-        # This is based on medialibrary's addDiscovererInfo method.
-        thumbnail_hash = md5(uri.encode()).hexdigest()
-        thumb_dir = os.path.expanduser("~/.thumbnails/normal/")
-        thumb_path_normal = thumb_dir + thumbnail_hash + ".png"
-        if os.path.exists(thumb_path_normal):
+        label_asset_info = Gtk.Label()
+        label_asset_info.set_markup(beautify_missing_asset(asset))
+        label_asset_info.set_xalign(0)
+        label_asset_info.set_yalign(0)
+        hbox.pack_start(label_asset_info, False, False, 0)
+
+        small_thumb, large_thumb = AssetThumbnail.get_thumbnails_from_xdg_cache(uri)
+        if large_thumb:
             self.debug("A thumbnail file was found for %s", uri)
-            thumbnail = Gtk.Image.new_from_file(thumb_path_normal)
-            thumbnail.set_padding(0, SPACING)
-            hbox.pack_start(thumbnail, False, False, 0)
+            thumbnail = Gtk.Image.new_from_pixbuf(large_thumb)
+            hbox.pack_end(thumbnail, False, False, 0)
 
-        # TODO: display the filesize to help the user identify the file
-        if asset.get_duration() == Gst.CLOCK_TIME_NONE:
-            # The file is probably an image, not video or audio.
-            text = _('The following file has moved: "<b>%s</b>"'
-                     '\nPlease specify its new location:'
-                     % info_name(asset))
-        else:
-            length = beautify_length(asset.get_duration())
-            text = _('The following file has moved: "<b>%s</b>" (duration: %s)'
-                     '\nPlease specify its new location:'
-                     % (info_name(asset), length))
+        vbox.pack_start(hbox, False, False, 0)
 
-        label = Gtk.Label()
-        label.set_markup(text)
-        hbox.pack_start(label, False, False, 0)
-        dialog.get_content_area().pack_start(hbox, False, False, 0)
-        hbox.show_all()
+        label_end = Gtk.Label()
+        label_end.set_markup(_("Please specify its new location:"))
+        label_end.set_xalign(0)
+        label_end.set_margin_top(PADDING)
+        vbox.pack_start(label_end, False, False, 0)
+
+        dialog.get_content_area().pack_start(vbox, False, False, 0)
+        vbox.show_all()
 
         chooser = Gtk.FileChooserWidget(action=Gtk.FileChooserAction.OPEN)
         chooser.set_select_multiple(False)
-        previewer = PreviewWidget(self.settings)
+        previewer = PreviewWidget(self.settings, discover_sync=True)
         chooser.set_preview_widget(previewer)
         chooser.set_use_preview_label(False)
         chooser.connect('update-preview', previewer.update_preview_cb)
@@ -981,7 +981,7 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
         filter_ = Gtk.FileFilter()
         # Translators: this is a format filter in a filechooser. Ex: "AVI
         # files"
-        filter_.set_name(_("%s files" % extension))
+        filter_.set_name(_("%s files") % extension)
         filter_.add_pattern("*%s" % extension.lower())
         filter_.add_pattern("*%s" % extension.upper())
         default = Gtk.FileFilter()
@@ -1011,8 +1011,8 @@ class MainWindow(Gtk.ApplicationWindow, Loggable):
                 # You have to do this *after* successfully creating a blank project,
                 # or the startupwizard will still be connected to that signal too.
                 reason = _('No replacement file was provided for "<i>%s</i>".\n\n'
-                           'Pitivi does not currently support partial projects.'
-                           % info_name(asset))
+                           'Pitivi does not currently support partial projects.') % \
+                    info_name(asset)
                 project_manager.emit("new-project-failed", project.uri, reason)
 
         dialog.destroy()
@@ -1303,7 +1303,7 @@ class PreviewAssetWindow(Gtk.Window):
 
         self._previewer = PreviewWidget(main_window.settings, minimal=True)
         self.add(self._previewer)
-        self._previewer.previewUri(self._asset.get_id())
+        self._previewer.preview_uri(self._asset.get_id())
         self._previewer.show()
 
         self.connect("focus-out-event", self._leavePreviewCb)
